@@ -22,12 +22,13 @@
 #include "ephy-uri-tester-shared.h"
 
 GFile *
-ephy_uri_tester_get_adblock_filter_file (const char *adblock_data_dir)
+ephy_uri_tester_get_adblock_filter_file (const char *adblock_data_dir,
+                                         const char *filter_url)
 {
   char *filter_filename, *filter_path;
   GFile *filter_file;
 
-  filter_filename = g_compute_checksum_for_string (G_CHECKSUM_MD5, ADBLOCK_FILTER_URL, -1);
+  filter_filename = g_compute_checksum_for_string (G_CHECKSUM_MD5, filter_url, -1);
   filter_path = g_build_filename (adblock_data_dir, filter_filename, NULL);
   g_free (filter_filename);
   filter_file = g_file_new_for_path (filter_path);
